/**
 *#########################################################################
 *
 * A component of the Gatherer application, part of the Greenstone digital
 * library suite from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * <BR><BR>
 *
 * Author: John Thompson, Greenstone Digital Library, University of Waikato
 *
 * <BR><BR>
 *
 * Copyright (C) 1999 New Zealand Digital Library Project
 *
 * <BR><BR>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * <BR><BR>
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * <BR><BR>
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *########################################################################
 */

 




/* GPL_HEADER */
package org.greenstone.gatherer.cdm;
/**************************************************************************************
 * Title:        Gatherer
 * Description:  The Gatherer: a tool for gathering and enriching a digital collection.
 * Company:      The University of Waikato
 * Written:      06/05/02
 * Revised:      04/10/02 - Commented
 **************************************************************************************/
import org.greenstone.gatherer.cdm.Classifier;
/** This class encapsulates all the information about a format command from the collection configuration. This includes both the 'general' formatting commands, and the commands targetted at specific classifiers or classification component types.
 * @author John Thompson, Greenstone Digital Library, University of Waikato
 * @version 2.3
 */
public class Format {
	 /** If this format is of a true/false type, the current state. */
	 private boolean state = false;
	 /** The type of this format command, either FLAG, FORMAT or PARAM. */
	 private int type = -1;
	 /** The feature this format command affects. */
	 private Object feature = null;
	 /** If this format refers to a specific part of a feature, this indicates the part. */
	 private String part = null;
	 /** A command string, which may include a specific HTML chunk used to format a control. */
	 private String value = null;
	 /** An element of the format type enumeration. A true/false option. */
	 static final public int FLAG = 0;
	 /** An element of the format type enumeration. A string parameter. */
	 static final public int VALUE = 1;
	 /** The default features as specified by the Greenstone Developers manual. */
	 static final public String DEFAULT_FEATURES[] = {"", "DocumentArrowsBottom","DocumentButtons","DocumentContents","DocumentHeading","DocumentImages","DocumentText","DocumentUseHTML","Search"};
	 /** The list of known feature parts. */
	 static final public String DEFAULT_PARTS[] = {"","DateList","HList","Invisible","VList"};
	 /** Constructor for a flag format command.
	 * @param feature The <Strong>Object</strong> this format affects.
	 * @param part The specific part of the control to format as a <strong>String</strong>.
	 * @param state A <i>boolean</i> indicating this formats state.
	 */
	 public Format(Object feature, String part, boolean state) {
		  this.feature = feature;
		  this.part = part;
		  this.state = state;
		  this.type = FLAG;
	 }
	 /** Constructor for a format-string format command.
	 * @param feature The <Strong>Object</strong> this format affects.
	 * @param part The specific part of the control to format as a <strong>String</strong>.
	 * @param value The format <strong>String</strong> which may be a label name, or a piece of HTML formatting.
	 */
	 public Format(Object feature, String part, String value) {
		  this.feature = feature;
		  this.part = part;
		  this.type = VALUE;
		  this.value = value;
	 }
	 /** Method to retrieve the value of feature, which may either be a String or a Classifier.
	  * @return The value of feature as an <strong>Object</strong>.
	  */
	 public Object getFeature() {
		  return feature;
	 }
	 /** Method to retrieve the value of part.
	  * @return The value of part as a <Strong>String</strong>.
	  */
	 public String getPart() {
		  return part;
	 }
	 /** Method to retrieve this formats special Greenstone position code.
	  * @return A <strong>String</strong> which distinctly indicates this classifiers position.
	  * @see org.greenstone.gatherer.cdm.Classifier
	  */
	 public String getPosition() {
		  ///ystem.err.println("Retrieving the name of feature " + feature);
		  String position = null;
		  if(feature instanceof Classifier) {
				position = ((Classifier)feature).getPositionString();
		  }
		  else {
				position = feature.toString();
		  }
		  ///ystem.err.println("Result: " + position + part);
		  return position + part;
	 }
	 /** Method to retrieve the value of state.
	  * @param The value of state as a <i>boolean</i>.
	  */
	 public boolean getState() {
		  return state;
	 }
	 /** Method to retrieve the value of type.
	  * @param The value of type as an <i>int</i>.
	  */
	 public int getType() {
		  return type;
	 }
	 /** Retrieve the value of value.
	  * @return A <strong>String</strong> which is the value of value.
	  */
	 public String getValue() {
		  return value;
	 }
	 /** Set the value of state.
	  * @param state The new value for state as a <i>boolean</i>.
	  */
	 public void setState(boolean state) {
		  this.state = state;
	 }
	 /** Set the value of type.
	  * @param type The new value for type as an <i>int</i>.
	  */
	 public void setType(int type) {
		  this.type = type;
	 }
	 /** Set the value of value. Hmmm.
	  * @param value The new value from value as a <strong>String</strong>.
	  */
	 public void setValue(String value) {
		  this.value = value;
	 }
	 /** Method to translate this classes information into a line of text as you would expect in the collection configuration file.
	  * @return A <strong>String</strong> containing the format command.
	  */
	 public String toString() {
		  String text = "format ";
		  text = text + getPosition() + " ";
		  switch(type) {
		  case FLAG:
				if(state) {
					 text = text + "true";
				}
				else {
					 text = text + "false";
				}
				break;
		  default:
				text = text + "\"" + value + "\"";
		  }
		  return text;
	 }
	 /** Retrieve the type of a certain named feature.
	  * @param name The name of the feature as a <strong>String</strong>.
	  * @return An <i>int</i> indicating the type, and hence the controls needed to edit this type.
	  */
	 static public int getType(String name) {
		  int index = -1;
		  for(int i = 1; i < DEFAULT_FEATURES.length; i++) {
				if(name.equalsIgnoreCase(DEFAULT_FEATURES[i])) {
					 index = i;
				}
		  }
		  if(index == 1 || index == 3 || index == 5 || index == 7) {
				return FLAG;
		  }
		  return VALUE;
	 }
}
